@@ -740,10 +740,9 @@ class CommandXRead : public Commander,
 
       std::vector<StreamEntry> result;
       auto s = stream_db.Range(streams_[i], options, &result);
-      if (!s.ok()) {
-        conn_->Reply(redis::MultiLen(-1));
-        LOG(ERROR) << "ERR executing XRANGE for stream " << streams_[i] << " from " << ids_[i].ToString() << " to "
-                   << options.end.ToString() << " with count " << count_ << ": " << s.ToString();
+      if (!s.ok() && !s.IsNotFound()) {
+        conn_->Reply(redis::Error("ERR " + s.ToString()));
+        return;
       }
 
       if (result.size() > 0) {
